Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(549)

Unified Diff: url/mojo/origin_struct_traits.h

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « url/mojo/origin.mojom ('k') | url/mojo/url_gurl_struct_traits_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: url/mojo/origin_struct_traits.h
diff --git a/url/mojo/origin_struct_traits.h b/url/mojo/origin_struct_traits.h
index 3b8d453eab9041404e5bda1708775805bd0579d6..296e97539c20148bdc366ecf0e296f90dbac9eb1 100644
--- a/url/mojo/origin_struct_traits.h
+++ b/url/mojo/origin_struct_traits.h
@@ -21,11 +21,9 @@ struct StructTraits<url::mojom::OriginDataView, url::Origin> {
static const std::string& suborigin(const url::Origin& r) {
return r.suborigin();
}
- static bool unique(const url::Origin& r) {
- return r.unique();
- }
+ static bool opaque(const url::Origin& r) { return r.opaque(); }
static bool Read(url::mojom::OriginDataView data, url::Origin* out) {
- if (data.unique()) {
+ if (data.opaque()) {
*out = url::Origin();
} else {
base::StringPiece scheme, host, suborigin;
@@ -37,10 +35,10 @@ struct StructTraits<url::mojom::OriginDataView, url::Origin> {
scheme, host, data.port(), suborigin);
}
// If a unique origin was created, but the unique flag wasn't set, then
// the values provided to 'UnsafelyCreateOriginWithoutNormalization' were
// invalid.
- if (!data.unique() && out->unique())
+ if (!data.opaque() && out->opaque())
return false;
return true;
« no previous file with comments | « url/mojo/origin.mojom ('k') | url/mojo/url_gurl_struct_traits_unittest.cc » ('j') | no next file with comments »
@@ -37,10 +35,10 @@ struct StructTraits<url::mojom::OriginDataView, url::Origin> {
scheme, host, data.port(), suborigin);
}
- // If a unique origin was created, but the unique flag wasn't set, then
+ // If an opaque origin was created, but the opaque flag wasn't set, then
// the values provided to 'UnsafelyCreateOriginWithoutNormalization' were
// invalid.

Powered by Google App Engine
This is Rietveld 408576698